# Copyright (C) 2024 Maxwell G <maxwell@gtmx.me>
# SPDX-License-Identifier: MIT
# License text: https://spdx.org/licenses/MIT

%bcond manpages 1
%global forgeurl https://gitlab.com/fedora/sigs/go/go-vendor-tools
%define tag v%{version_no_tilde %{quote:%nil}}

Name:           go-vendor-tools
Version:        0.5.1^42.20240812.c6a9180
%forgemeta
Release:        1%{?dist}
Summary:        Tools for handling Go library vendoring in Fedora [SEE NOTE IN DESCRIPTION]

# BSD-3-Clause: src/go_vendor_tools/archive.py
License:        MIT AND BSD-3-Clause
URL:            %{forgeurl}
Source0:        go-vendor-tools-0.5.1^42.20240812.c6a9180.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel

%if %{with manpages}
BuildRequires:  scdoc
%endif

Recommends:     (askalono-cli or trivy)
Recommends:     go-vendor-tools+all


%global common_description %{expand:
go-vendor-tools provides tools and macros for handling Go library vendoring in
Fedora.

STABILITY NOTE:

go-vendor-tools is under active development and available in the stable Fedora
and Fedora EPEL repos for testing purposes.
Expect some breaking changes between releases.
Anyone using the `%%go_vendor_*` macros in active Fedora packages MUST join the
Fedora Golang Matrix room and Fedora Go SIG mailing list to be notified of any
major changes.}

%description %common_description


%package doc
Summary:        Documentation for go-vendor-tools
Enhances:       go-vendor-tools

%description doc %common_description


%prep
%autosetup -p1 


%generate_buildrequires
%pyproject_buildrequires -x all,test


%build
%pyproject_wheel
%if %{with manpages}
./doc/man/mkman.sh
%endif

mkdir -p bash_completions fish_completions zsh_completions
for bin in go_vendor_archive go_vendor_license; do
    register-python-argcomplete --shell bash "${bin}" > "bash_completions/${bin}"
    register-python-argcomplete --shell fish "${bin}" > "fish_completions/${bin}.fish"
    # Compatibility with old argcomplete versions
    if ! (register-python-argcomplete --shell zsh "${bin}" > "zsh_completions/_${bin}"); then
        echo "#compdef ${bin}" > "zsh_completions/_${bin}"
        echo -e "autoload -Uz bashcompinit\nbashcompinit" > "zsh_completions/_${bin}"
        cat "bash_completions/${bin}" >> "zsh_completions/_${bin}"
    fi
done


%install
%pyproject_install
# TODO(anyone): Use -l flag once supported by EL 9.
%pyproject_save_files go_vendor_tools

# Install RPM macros
install -Dpm 0644 rpm/macros.go_vendor_tools -t %{buildroot}%{_rpmmacrodir}

# Install documentation
mkdir -p %{buildroot}%{_docdir}/go-vendor-tools-doc
cp -rL doc/* %{buildroot}%{_docdir}/go-vendor-tools-doc

# Install manpages
%if %{with manpages}
install -Dpm 0644 doc/man/*.1 -t %{buildroot}%{_mandir}/man1/
%endif

# Install completions
install -Dpm 0644 bash_completions/* -t %{buildroot}%{bash_completions_dir}/
install -Dpm 0644 fish_completions/* -t %{buildroot}%{fish_completions_dir}/
install -Dpm 0644 zsh_completions/* -t %{buildroot}%{zsh_completions_dir}/


%check
%pytest


%files -f %{pyproject_files}
# Install top-level markdown files
%doc *.md
%license LICENSES/*
%{_bindir}/go_vendor*
%{bash_completions_dir}/go_vendor_*
%{fish_completions_dir}/go_vendor_*.fish
%{zsh_completions_dir}/_go_vendor_*
%{_rpmmacrodir}/macros.go_vendor_tools
%if %{with manpages}
%{_mandir}/man1/go*.1*
%endif

%files doc
%doc %{_docdir}/go-vendor-tools-doc/

%pyproject_extras_subpkg -n go-vendor-tools all

%changelog
* Mon Aug 12 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^42.20240812.c6a9180-1
- tests: raise total coverage to 90%%

* Mon Aug 12 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^41.20240812.e91372c-1
- lint reuse: switch to new REUSE.toml config

* Mon Aug 12 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^40.20240812.fdfadc7-1
- lint go_vendor_license: add missing function annotation

* Mon Aug 12 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^39.20240812.712b427-1
- go_vendor_license: exit with error code when no backends are available

* Mon Aug 12 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^38.20240812.5a1cbe6-1
- lint coverage: ignore `except ImportError` blocks

* Mon Aug 12 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^37.20240812.126cf9b-1
- scancode: raise exception when scancode_toolkit is not installed

* Mon Aug 12 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^36.20240812.b8c2a67-1
- go_vendor_license: fix typo in error message

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^35.20240811.18cff56-1
- doc config: document new scancode-toolkit backend

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^34.20240811.d09a055-1
- packaging: fixup scancode extra removal in tests

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^33.20240811.0eaa921-1
- contrib requirements: add missing click dependency

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^32.20240811.80b2830-1
- lint editorconfig: add explicit filetypes

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^31.20240811.08f2bd2-1
- packaging: remove scancode extra

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^30.20240811.ac74fc6-1
- doc CONTRIBUTING: fix Copr + Mock instructions

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^29.20240811.22920fa-1
- contrib: add whatrequires_branches script

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^28.20240811.f158f29-1
- doc CONTRIBUTING: fix typo and clarify headings

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^27.20240811.cb32d1c-1
- doc CONTRIBUTING: add additional sections about testing

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^26.20240811.d3110f2-1
- tests integration: clean up specs and scripts and add scancode

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^25.20240811.de11557-1
- rpm: use %%{go_vendor_license_filelist} in the other macros

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^24.20240811.bd7b879-1
- ci: disable Fedora 41 Python 3.13 tests for now

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^23.20240811.f56243f-1
- license_detection: add `scancode-toolkit`-based backend

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^22.20240811.20b42d3-1
- LicenseData: allow customizing combine_licenses call in subclasses

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^21.20240811.61f815f-1
- licensing combine_licenses: add recursive_simplify arg; correct types

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^20.20240811.704d299-1
- go_vendor_license write_license_json: use pretty formatting for JSON

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^19.20240811.2a0f8a4-1
- license_detection base: add docstring to `find_extra_license_files()`

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^18.20240811.b39693e-1
- go_vendor_license: properly test relative and absolute paths

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^17.20240811.fc79ce4-1
- license_detection: include PATENTS in EXTRA_LICENSE_FILE_REGEX

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^16.20240811.4d31ab5-1
- lint config: remove total=False from TypedDicts

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^15.20240811.6501e75-1
- lint license_detection: prefix private LicenseDataT with _

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^14.20240811.05166c2-1
- lint license_detection: clarify manual license entry variable names

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^13.20240811.e97c1e1-1
- lint: add editorconfig

* Sun Aug 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^12.20240811.9078984-1
- lint pyright lsp: enable basic type checking

* Mon Aug 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^11.20240805.fc35cd9-1
- go_vendor_archive: add support for go workspaces

* Mon Aug 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^10.20240805.3211955-1
- doc: add note about project stability

* Fri Jul 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^9.20240705.3d3cc54-1
- nox integration: remove fclogr dependency

* Fri Jul 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^8.20240705.b227d49-1
- nox: set error_on_external_run

* Fri Jul 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^7.20240705.01951b3-1
- go_vendor_license: work around bug with old tomlkit versions

* Sun Jun 23 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^6.20240623.f09ff94-1
- go_vendor_license: fix printing of undetected licenses

* Fri May 03 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^5.20240503.887b35b-1
- license_detection: make askalono the default backend

* Fri May 03 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^4.20240503.a459863-1
- lint doc: enable pymarkdownlnt for the doc folder

* Fri May 03 2024 Brad Smith <bradley.g.smith@gmail.com> - 0.5.1^3.20240503.735e24d-1
- doc scenarios: add new upstream version scenario

* Thu May 02 2024 Brad Smith <bradley.g.smith@gmail.com> - 0.5.1^2.20240502.54a475f-1
- doc: update mkdocs URLs to go-sig Gitlab namespace

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^1.20240411.fc9513a-1
- Post-release version bump

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1-1
- Release 0.5.1.

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.0-1
- Release 0.5.0.

* Wed Apr 10 2024 Maxwell G <maxwell@gtmx.me> - 0.4.0-1
- Release 0.4.0.

* Wed Apr 10 2024 Maxwell G <maxwell@gtmx.me> - 0.4.0~b1-1
- Release 0.4.0b1.

* Thu Mar 28 2024 Maxwell G <maxwell@gtmx.me> - 0.3.0-1
- Release 0.3.0.

* Sat Mar 16 2024 Maxwell G <maxwell@gtmx.me> - 0.2.0-1
- Release 0.2.0.

* Sat Mar 09 2024 Maxwell G <maxwell@gtmx.me> - 0.1.0-1
- Release 0.1.0.

* Tue Mar 05 2024 Maxwell G <maxwell@gtmx.me> - 0.0.1-1
- Release 0.0.1.
